Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1032)

Unified Diff: webrtc/video/video_send_stream.h

Issue 1993113003: Refactor how padding is calculated. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Fixed unitialized memory. Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/video/video_send_stream.h
diff --git a/webrtc/video/video_send_stream.h b/webrtc/video/video_send_stream.h
index df3e3c4c638d99408d87075bdf2ffba4c05b9575..b7448dd8b7ca3b06a420431d1f79832fb3190e78 100644
--- a/webrtc/video/video_send_stream.h
+++ b/webrtc/video/video_send_stream.h
@@ -52,7 +52,7 @@ class VideoSendStream : public webrtc::VideoSendStream,
public webrtc::CpuOveruseObserver,
public webrtc::BitrateAllocatorObserver,
public webrtc::VCMProtectionCallback,
- protected webrtc::EncodedImageCallback {
+ public VideoEncoderSink {
public:
VideoSendStream(int num_cpu_cores,
ProcessThread* module_process_thread,
@@ -103,17 +103,18 @@ class VideoSendStream : public webrtc::VideoSendStream,
private:
struct EncoderSettings {
VideoCodec video_codec;
- int min_transmit_bitrate_bps;
- std::vector<VideoStream> streams;
+ VideoEncoderConfig config;
};
// Implements EncodedImageCallback. The implementation routes encoded frames
// to the |payload_router_| and |config.pre_encode_callback| if set.
// Called on an arbitrary encoder callback thread.
int32_t Encoded(const EncodedImage& encoded_image,
const CodecSpecificInfo* codec_specific_info,
const RTPFragmentationHeader* fragmentation) override;
+ void OnEncoderActivityChanged(bool active) override;
+
static bool EncoderThreadFunction(void* obj);
void EncoderProcess();
@@ -103,17 +103,18 @@ class VideoSendStream : public webrtc::VideoSendStream,
};
- // Implements EncodedImageCallback. The implementation routes encoded frames
+ // Implements VideoEncoderSink. The implementation routes encoded frames
// to the |payload_router_| and |config.pre_encode_callback| if set.
// Called on an arbitrary encoder callback thread.

Powered by Google App Engine
This is Rietveld 408576698